@@ -4,6 +4,8 @@
 #![deny(missing_docs)]
 //! This is a way to "transmute" Vecs soundly.
 //! ```
+//! # #[cfg(feature = "allocator_api")]
+//! # {
 //! #![feature(allocator_api)] // this requires the allocator api because the way that this
 //! // handles deallocating hooks into the allocator api
 //! use transvec::transmute_vec;
@@ -25,11 +27,14 @@
 //!         &[1, 0, 2, 0, 3, 0, 4, 0, 5, 0, 6, 0, 7, 0, 8, 0]
 //!     );
 //! }
+//! # }
+//! ```
 
 extern crate alloc;
 
 use alloc::vec::Vec;
 use bytemuck::Pod;
+
 #[cfg(feature = "allocator_api")]
 use core::alloc::{AllocError, Allocator, Layout};
 use core::{
@@ -301,6 +306,30 @@ pub fn transmute_vec_copy_enum<I: Pod, O: Pod, A: Allocator>(input: Vec<I, A>) -
     }
 }
 
+#[cfg(feature = "allocator_api")]
+/// Changes from any allocator to an [`AlignmentCorrectorAllocator`].
+pub fn add_alignment_allocator<I: Pod, O: Pod, A: Allocator>(
+    input: Vec<O, A>,
+) -> Vec<O, AlignmentCorrectorAllocator<I, O, A>> {
+    let (ptr, length, capacity, allocator) = {
+        let mut me = ManuallyDrop::new(input);
+        (me.as_mut_ptr(), me.len(), me.capacity(), unsafe {
+            ptr::read(me.allocator())
+        })
+    };
+
+    // SAFETY: comes directly from vec and AlignmentCorrectorAllocator::new_null
+    // doesn't interfere with the allocator within
+    unsafe {
+        Vec::from_raw_parts_in(
+            ptr,
+            length,
+            capacity,
+            AlignmentCorrectorAllocator::new_null(allocator),
+        )
+    }
+}
+
 #[cfg(feature = "allocator_api")]
 /// Same as `transmute_vec` but in case of an error it copies instead.
 /// If it's over the length it removes whatever doesn't fit.
@@ -497,16 +526,16 @@ pub fn transmute_vec<I: Pod, O: Pod, A: Allocator>(
 /// 1. The length of the vector wouldn't fit the type.
 /// ```should_panic
 /// # #![feature(allocator_api)]
-/// # use transvec::transmute_vec;
+/// # use transvec::transmute_vec_basic;
 /// let input: Vec<u8> = vec![1, 2, 3];
-/// let output: Vec<u16, _> = transmute_vec(input).unwrap();
+/// let output: Vec<u16, _> = transmute_vec_basic(input).unwrap();
 /// ```
 /// 2. The capacity can't be converted to units of the output type.
 /// ```should_panic
 /// # #![feature(allocator_api)]
-/// # use transvec::transmute_vec;
+/// # use transvec::transmute_vec_basic;
 /// let input: Vec<u8> = Vec::with_capacity(3);
-/// let output: Vec<u16, _> = transmute_vec(input).unwrap();
+/// let output: Vec<u16, _> = transmute_vec_basic(input).unwrap();
 /// ```
 /// Length, then capacity will be returned.
 /// # ZSTs
@@ -515,7 +544,7 @@ pub fn transmute_vec<I: Pod, O: Pod, A: Allocator>(
 /// 2. ZST -> Non ZST
 ///     - New Vec from previous allocator.
 /// 3. Just don't do this.
-/// 
+///
 /// # Panics
 /// Panics if the alignment is not the same.
 /// (This may be turned into a compile time error in the future, when possible without using nightly
@@ -615,13 +644,11 @@ pub fn transmute_vec_basic_copy<I: Pod, O: Pod>(input: Vec<I>) -> Vec<O> {
 #[cfg(test)]
 mod tests {
 
+    #[cfg(feature = "allocator_api")]
+    use crate::{transmute_vec, transmute_vec_may_copy};
+    use crate::{transmute_vec_basic, transmute_vec_basic_copy, TransmuteError};
     use alloc::{vec, vec::Vec};
 
-    use crate::{
-        transmute_vec, transmute_vec_basic, transmute_vec_basic_copy, transmute_vec_may_copy,
-        TransmuteError,
-    };
-
     #[test]
     #[cfg(feature = "allocator_api")]
     // It does work with the same sized types
@@ -716,6 +743,7 @@ mod tests {
     }
 
     #[test]
+    #[cfg(feature = "allocator_api")]
     fn wrong_length() {
         let input: Vec<u8> = vec![1, 2, 3];
         match transmute_vec::<_, u16, _>(input) {
